@@ -4,7 +4,7 @@
 
 # pylint: disable=wrong-import-position,wrong-import-order
 from datetime import timedelta
-from unitbench import Benchmark
+from bench.unitbench import Benchmark
 from test.fixtures import payload, priv_keys, priv_key, pub_keys, pub_key, algs
 from bench.reporter import Reporter
 import python_jwt as jwt
